import { Request, Response } from "express";
import Store from "../models/store";
import { getUserSession } from "../utils/utils";

export async function GetStore(req: Request, res: Response) {
  try {
    const { storeId } = req.params;

    if (!storeId) {
      return res.status(400).send({ err: "invalid request" });
    }

    // check if requester is the store owner

    const userSession = await getUserSession(req);

    if (!userSession) {
      return res.status(401).send({ err: "unauthorized" });
    }

    const store = await Store.findOne({
      where: {
        store_id: storeId,
      },
      attributes: ["owner_user_id", "name"],
    });

    if (!store) {
      return res.status(400).send({ err: "invalid request" });
    }

    if (store.owner_user_id !== userSession.user_id) {
      return res.status(401).send({ err: "unauthorized" });
    }

    res.status(200).send({ store: { name: store.name } });
  } catch (error) {
    res.status(500).send({ err: "invalid request" });
  }
}
