import { DataTypes, Model } from "sequelize";
import sequelize from "../database/database";

interface UserAttributes {
  user_id: string;
  store_id: string;
  // TODO: change to role_id
  role: string;
  account_name: string;
  username: string;
  password: string;
  calendar_max_future_booking_days?: number;
  calendar_min_earliest_booking_time?: number;
  calendar_primary_calendar_id?: string;
  calendar_using_primary_calendar?: boolean;
}

class User extends Model<UserAttributes> implements UserAttributes {
  declare user_id: string;
  declare store_id: string;
  declare role: string;
  declare account_name: string;
  declare username: string;
  declare password: string;
  declare calendar_max_future_booking_days: number;
  declare calendar_min_earliest_booking_time: number;
  declare calendar_primary_calendar_id: string;
  declare calendar_using_primary_calendar: boolean;
}

User.init(
  {
    // Model attributes are defined here
    user_id: {
      primaryKey: true,
      type: DataTypes.STRING,
      allowNull: false,
    },
    store_id: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    role: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    account_name: {
      type: DataTypes.STRING,
      unique: true,
    },
    username: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    password: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    calendar_max_future_booking_days: {
      type: DataTypes.INTEGER,
    },
    calendar_min_earliest_booking_time: {
      type: DataTypes.INTEGER,
    },
    calendar_primary_calendar_id: {
      type: DataTypes.STRING,
    },
    calendar_using_primary_calendar: {
      type: DataTypes.BOOLEAN,
    },
  },
  {
    tableName: "users",
    sequelize, // passing the `sequelize` instance is required
  }
);

export default User;
